# Changelog

All notable changes to this project will be documented in this file.

## v0.3.1

### Changed

- Use `__slots__` to optimize memory usage.

## v0.3.0

### Added

- Added `YearMonth.distance_to()` method for calculating the distance between two `YearMonth` instances.

## v0.2.0

### Added

- Added support for membership test operators (`in` and `not in`) for checking if a `date` or `datetime` falls within a `YearMonth`.

### Changed

- Improved `YearMonth.parse()` performance.

## v0.1.0

- Initial release.
